@@ -1,10 +1,25 @@
 from ctreport_selenium.utility_classes import Severity
 
 
-def chart(count):
+def chart(theme, count):
     pass_ = str(count[0])
     fail_ = str(count[1])
     label = Severity.BLOCKER.capitalize()
+    legend_labels = '''
+                labels: {
+					fontColor:'#fff'
+				}
+				''' if theme == "Dark Angel" else ""
+    xAxis_ticks_gridlines = '''ticks: {
+                            fontColor: '#fff'
+                        },
+    					gridLines: {
+    					  color: "rgba(176, 92, 94,0.5)",
+    					}''' if theme == "Dark Angel" else ""
+    yAxis_gridlines = '''
+                        gridLines: {
+    					  color: "rgba(176, 92, 94,0.5)",
+    					}''' if theme == "Dark Angel" else ""
     content = '''
         new Chart(document.getElementById("assertionchart"), {
         type: 'bar',
@@ -25,15 +40,17 @@ def chart(count):
           title: {
             fontSize:20,
             display: false,
-            text: 'Group under Priority'
+            text: 'Group Assertion under Severity'
           },
           legend: {
-            position:'bottom'
+            position:'bottom',
+            '''+legend_labels+'''
           },
           scales: {
             xAxes: [{
                 barThickness : 40,
-                barPercentage: 19,			
+                barPercentage: 19,	
+                '''+xAxis_ticks_gridlines+'''		
             }],
             yAxes: [{
                 display: true,
@@ -41,7 +58,8 @@ def chart(count):
                     display: false,
                     maxTicksLimit: 6,
                     precision:0,
-				}
+				},
+				'''+yAxis_gridlines+'''
             }],
           }
         }
